FileCabinetReader
=================

.. currentmodule:: wwt_data_formats.filecabinet

.. autoclass:: FileCabinetReader
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~FileCabinetReader.close
      ~FileCabinetReader.filenames
      ~FileCabinetReader.read_file

   .. rubric:: Methods Documentation

   .. automethod:: close
   .. automethod:: filenames
   .. automethod:: read_file
